@@ -15,7 +15,8 @@ class Model(nn.Module):
         super().__init__()
         self.tokenizer = tokenizer
         self.pretrained = pretrained
-        self.model = nn.Linear(self.pretrained.config.hidden_size, self.tokenizer.__len__())
+        self.vocab_size = max(self.pretrained.config.vocab_size, self.tokenizer.__len__())
+        self.model = nn.Linear(self.pretrained.config.hidden_size, self.vocab_size)
         self.maxlen = maxlen
         self.device = 'cuda' if torch.cuda.is_available() else 'cpu'
         print('Using device:', self.device)
@@ -50,8 +51,8 @@ class Model(nn.Module):
             while start < self.maxlen and not stop:
                 predicted_index = torch.argmax(prediction_scores[0][start]).item()
                 predicted_token = self.tokenizer.decode([predicted_index])
-                topK = torch.topk(softmax(prediction_scores[0][start], dim=0), 50)
-                logit_prob = softmax(prediction_scores[0][start], dim=0).data.tolist()
+                logit_prob = softmax(prediction_scores[0][start], dim=0)
+                topK = torch.topk(logit_prob, 50)
                 prob_result = [(self.tokenizer.convert_ids_to_tokens(id), prob) for prob, id in
                                zip(topK.values.data.tolist(), topK.indices.data.tolist())]
 
@@ -65,11 +66,11 @@ class Model(nn.Module):
                 outputs = result_dict
         else:
             loss_fct = nn.CrossEntropyLoss(ignore_index=-1)  # -1 index = padding token
-            masked_lm_loss = loss_fct(prediction_scores.view(-1, self.pretrained.config.vocab_size),
+            masked_lm_loss = loss_fct(prediction_scores.view(-1, self.vocab_size),
                                       loss_tensors.view(-1))
             if not torch.all(negativeloss_tensors.eq(-1)).item():
                 negative_loss_fct = NegativeCElLoss().to(self.device)
-                negative_loss = negative_loss_fct(prediction_scores.view(-1, self.pretrained.config.vocab_size),
+                negative_loss = negative_loss_fct(prediction_scores.view(-1, self.vocab_size),
                                                   negativeloss_tensors.view(-1))
                 masked_lm_loss += negative_loss
             outputs = masked_lm_loss
